@@ -4,6 +4,7 @@ from __future__ import division
 
 from math import cos
 from math import pi
+from copy import deepcopy
 
 from compas.geometry import centroid_points
 
@@ -22,10 +23,23 @@ __all__ = [
 ]
 
 
-class SubdMesh(Mesh):
+def mesh_fast_copy(other):
+    subd = SubdMesh()
+    subd.attributes = deepcopy(other.attributes)
+    subd.default_vertex_attributes = deepcopy(other.default_vertex_attributes)
+    subd.default_face_attributes = deepcopy(other.default_face_attributes)
+    subd.default_edge_attributes = deepcopy(other.default_edge_attributes)
+    subd.vertex = deepcopy(other.vertex)
+    subd.face = deepcopy(other.face)
+    subd.edgedata = deepcopy(other.edgedata)
+    subd.facedata = deepcopy(other.facedata)
+    subd.halfedge = deepcopy(other.halfedge)
+    subd._max_int_key = other._max_int_key
+    subd._max_int_fkey = other._max_int_fkey
+    return subd
 
-    # def vertex_coordinates(self, key):
-    #     return self.vertex[key]
+
+class SubdMesh(Mesh):
 
     def add_vertex(self, x, y, z):
         key = self._max_int_key = self._max_int_key + 1
@@ -116,46 +130,37 @@ def mesh_subdivide_tri(mesh, k=1):
         A new subdivided mesh.
 
     """
-
     for _ in range(k):
         subd = mesh.copy()
-
         for fkey in mesh.faces():
             subd.insert_vertex(fkey)
-
         mesh = subd
-
     return mesh
 
 
 def mesh_subdivide_quad(mesh, k=1):
     """Subdivide a mesh such that all faces are quads.
     """
-
+    # cls = type(mesh)
     for _ in range(k):
+        # subd = mesh_fast_copy(mesh)
         subd = mesh.copy()
-
         for u, v in list(subd.edges()):
             mesh_split_edge(subd, u, v, allow_boundary=True)
-
         for fkey in mesh.faces():
-
             descendant = {i: j for i, j in subd.face_halfedges(fkey)}
             ancestor = {j: i for i, j in subd.face_halfedges(fkey)}
-
             x, y, z = mesh.face_centroid(fkey)
             c = subd.add_vertex(x=x, y=y, z=z)
-
             for key in mesh.face_vertices(fkey):
                 a = ancestor[key]
                 d = descendant[key]
                 subd.add_face([a, key, d, c])
-
             del subd.face[fkey]
-
         mesh = subd
-
-    return mesh
+    # subd = cls()
+    # subd.data = mesh.data
+    return subd
 
 
 def mesh_subdivide_corner(mesh, k=1):
@@ -241,76 +246,7 @@ def mesh_subdivide_catmullclark(mesh, k=1, fixed=None):
 
     Examples
     --------
-    .. plot::
-        :include-source:
-
-        from compas.datastructures import Mesh
-        from compas.datastructures import mesh_subdivide_catmullclark
-        from compas_plotters import MeshPlotter
-
-        vertices = [[0., 0., 0.], [1., 0., 0.], [1., 1., 0.], [0., 1.0, 0.]]
-        faces = [[0, 1, 2, 3]]
-
-        mesh = Mesh.from_vertices_and_faces(vertices, faces)
-        subd = mesh_subdivide_catmullclark(mesh, k=3, fixed=mesh.vertices())
-
-        plotter = MeshPlotter(subd)
-
-        plotter.draw_vertices(facecolor={key: '#ff0000' for key in mesh.vertices()}, radius=0.01)
-        plotter.draw_faces()
-
-        plotter.show()
-
-
-    .. plot::
-        :include-source:
-
-        from compas.datastructures import Mesh
-        from compas.datastructures import mesh_subdivide_catmullclark
-        from compas_plotters import MeshPlotter
-
-        vertices = [[0., 0., 0.], [1., 0., 0.], [1., 1., 0.], [0., 1.0, 0.]]
-        faces = [[0, 1, 2, 3]]
-
-        mesh = Mesh.from_vertices_and_faces(vertices, faces)
-        subd = mesh_subdivide_catmullclark(mesh, k=3, fixed=None)
-
-        plotter = MeshPlotter(subd)
-
-        plotter.draw_vertices(facecolor={key: '#ff0000' for key in mesh.vertices()}, radius=0.01)
-        plotter.draw_faces()
-
-        plotter.show()
-
-
-    .. code-block:: python
-
-        from compas.datastructures import Mesh
-        from compas.datastructures import mesh_subdivide_catmullclark
-        from compas.geometry import Polyhedron
-        from compas_viewers import SubdMeshViewer
-
-        cube = Polyhedron.generate(6)
-
-        mesh = Mesh.from_vertices_and_faces(cube.vertices, cube.faces)
-
-        viewer = SubdMeshViewer(mesh, subdfunc=mesh_subdivide_catmullclark, width=1440, height=900)
-
-        viewer.axes_on = False
-        viewer.grid_on = False
-
-        for _ in range(10):
-           viewer.camera.zoom_in()
-
-        viewer.subdivide(k=4)
-
-        viewer.setup()
-        viewer.show()
-
-
-    .. figure:: /_images/subdivide_mesh_catmullclark-screenshot.*
-        :figclass: figure
-        :class: figure-img img-fluid
+    >>>
 
     """
     if not fixed:
